     function [ a,b,siga,sigb,rms,wrms ]= wmlsline(x,y,w)
%
%              wmlsline
%                        weighted mean least squares line fit
%                 
%    input:
%              x    independent variable 
%              y    data - modeled as y= a + b*x
%              w    weight  each measurement is weighted as
%                   1/w(i)  --- typically w = variance estimate
%
%
%    output:
%              a,b  = parameters 1 and 2
%              P    = covariance, assumeing R=I*sigma omitting sigma
%
%
     lenv = size(x);
     nobs = max(lenv);
%
     iter = 0;
     done = 0;
%
%                   linear so just start at 0
%
     az  = 0;
     bz  = 0;
%
     a   =  az;
     b   =  bz;
%
%    -----------------------------------------------------------
%
%                   iterate even though linear - later expand
%                   for sigma editing
%
%
      while (~done)
%
          iter   =  iter + 1;
%
          omc    =  [];
          htwr   =  zeros(2,1);
          htwh   =  zeros(2,2);
          htwwh  =  zeros(2,2);
%
%              de-bias the data 
%
          xbias = x(1);
          abias = b*xbias;
          ause  = a + abias;
%
          for  im=1:nobs
%
             xn = x(im)-xbias;
             yn = y(im);
             wn = w(im);
%
             yc  = ause + b*xn;
             omc = yn - yc;
%
             p1  = 1;
             p2  = xn;
%
             htwh(1,1)  =  htwh(1,1) + p1*wn*p1;
             htwh(1,2)  =  htwh(1,2) + p1*wn*p2;
             htwh(2,1)  =  htwh(2,1) + p2*wn*p1;
             htwh(2,2)  =  htwh(2,2) + p2*wn*p2;
%
%
             htwwh(1,1)  =  htwwh(1,1) + p1*wn*wn*p1;
             htwwh(1,2)  =  htwwh(1,2) + p1*wn*wn*p2;
             htwwh(2,1)  =  htwwh(2,1) + p2*wn*wn*p1;
             htwwh(2,2)  =  htwwh(2,2) + p2*wn*wn*p2;
%
             htwr(1)    =  htwr(1)   + p1*wn*omc;
             htwr(2)    =  htwr(2)   + p2*wn*omc;
%
          end
%
          htwhi   = inv ( htwh );
          dx      = htwhi * htwr;
%
          da      = dx(1);
          db      = dx(2);
%
          p       = htwhi*htwwh*htwhi;
%
          siga    = sqrt(p(1,1));
          sigb    = sqrt(p(2,2));
%
          ause    = ause  + da;
          b       = b     + db;
%
          if iter > 1, done=1; end;
%
      end
%
      a  =  ause - abias;
%
%-------------------------------------------------------------
%
%         raw and weighted rms
%
     rms   = 0;
     wrms  = 0;
     sw    = 0;
%
     for im = 1:nobs
%
         xn  =  x(im);
         yn  =  y(im);
         omc =  yn - ( a + b*xn );
%
         wn  =  w(im);
%
         rms =  rms  + omc*omc;
         wrms=  wrms + omc*wn*omc;
         sw  =  sw   + wn;
%
    end
%
         rms   = sqrt( rms/nobs);
         wrms  = sqrt ( wrms/ sw );
%
%    ----------------------------------------------------
%
        return
